from .cnn.lenet import LeNet
from .cnn.resnet import ResNet
from .cnn.alexnet import AlexNet
from .cnn.shallownet import ShallowNet 
from .cnn.minivggnet import MiniVGGNet
from .cnn.agegendernet import AgeGenderNet
from .cnn.minigooglenet import MiniGoogLeNet
from .cnn.deepergooglenet import DeeperGoogLeNet

from .visualize.scatter import point_scatter